# pyzengin
pyzengin is the bank codes and branch codes for Japanese.

## Acknowledgment

Source data by http://ykaku.com/ginkokensaku/index.php

## License

This repository is available as open source under the terms of the MIT License.
